==> dde-control-center_5.5.149.orig.tar.xz: dde-control-center-5.5.149/translations/recovery_en.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="33"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Rolling back the system, please wait...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="250"/>
        <source>Rollback failed.</source>
        <translation>Rollback failed.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="255"/>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="264"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Are you sure you want to roll back to %1 backed up on %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="267"/>
        <source>Cancel and Reboot</source>
        <translation>Cancel and Reboot</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="268"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
</context>
</TS>

==> dde-control-center_5.5.156.orig.tar.xz: dde-control-center-5.5.156/translations/recovery_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="33"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <source>Rolling back the system, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="250"/>
        <source>Rollback failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="255"/>
        <source>Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="264"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="267"/>
        <source>Cancel and Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="268"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
